@@ -485,9 +485,7 @@ configoption_t *dotconf_find_command(configfile_t *configfile, const char *comma
 
 void dotconf_set_command(configfile_t *configfile, const configoption_t *option, signed char *args, command_t *cmd)
 {
-	signed char *eob = 0;
-
-	eob = args + strlen(args);
+	signed char *eob = args + strlen(args);
 
 	/* fill in the command_t structure with values we already know */
 	cmd->name = option->type == ARG_NAME ? name : option->name;
@@ -506,7 +504,7 @@ void dotconf_set_command(configfile_t *configfile, const configoption_t *option,
 		signed char *cp = args;
 
 		/* check if it's a here-document and act accordingly */
-		skip_whitespace(&cp, (int)eob - (int)cp, 0);
+		skip_whitespace(&cp, eob - cp, 0);
 
 		if (!strncmp("<<", cp, 2)) {
 			cmd->data.str = dotconf_get_here_document(configfile, cp + 2);
@@ -605,7 +603,7 @@ const char *dotconf_handle_command(configfile_t *configfile, char *buffer)
 	cp1 = buffer;
 	eob = cp1 + strlen(cp1);
 
-	skip_whitespace(&cp1, (int)eob - (int)cp1, 0);
+	skip_whitespace(&cp1, eob - cp1, 0);
 
 	/* ignore comments and empty lines */
 	if (!cp1 || !*cp1 || *cp1 == '#' || *cp1 == '\n' || *cp1 == EOF)
